@@ -1,5 +1,6 @@
 import asyncio
 import datetime
+from sys import getsizeof
 
 from asgiref.sync import sync_to_async
 from django.db import models as django_models
@@ -315,7 +316,6 @@ def django_to_cache(
         completed = 0
         to_complete = len(django_instances)
         if django_instances:
-            all_redis_instances = redis_root.get(django_model)
 
             for django_instance in django_instances:
                 async_tasks.append(
@@ -323,7 +323,6 @@ def django_to_cache(
                         redis_root,
                         django_instance,
                         django_fields,
-                        all_redis_instances,
                         cache_conf,
                     )
                 )
@@ -370,22 +369,18 @@ async def update_or_create_redis_instance_from_django_instance(
         redis_root,
         django_instance,
         django_fields,
-        all_redis_instances,
         cache_conf,
 ):
 
     django_instance_model = django_instance.__class__
-    old_redis_instance = get_redis_instance_by_django_id_from_all_redis_instances(
-        django_instance.id,
-        all_redis_instances
-    )
+    old_redis_instance = redis_root.get(django_instance_model, django_id=django_instance.id)
     redis_dict = await django_instance_to_redis_params(
         redis_root,
         django_instance,
         django_fields,
         cache_conf,
     )
-    print(django_instance_model, django_instance.id)
+
     if not old_redis_instance:
         fields_to_create = redis_dict
         redis_instance = redis_root.create(
@@ -395,6 +390,7 @@ async def update_or_create_redis_instance_from_django_instance(
         )
         result_redis_instance_id = redis_instance['id']
     else:
+        old_redis_instance = old_redis_instance[0]
         fields_to_update = check_fields_need_to_update(
             old_redis_instance,
             redis_dict,
@@ -445,11 +441,9 @@ async def django_instance_field_to_redis_value(
             if save_related_models:
                 if django_foreign_key_instance:
                     django_instance_model = django_foreign_key_instance.__class__
-                    all_redis_instances = redis_root.get(django_instance_model)
                     redis_foreign_key_instance = await get_or_create_redis_instance_from_django_instance(
                         django_foreign_key_instance,
                         redis_root,
-                        all_redis_instances,
                         cache_conf,
                     )
                     redis_value = redis_foreign_key_instance
@@ -462,12 +456,10 @@ async def django_instance_field_to_redis_value(
         if save_related_models:
             if len(django_many_to_many_instances):
                 django_instance_model = django_many_to_many_instances[0].__class__
-                all_redis_instances = redis_root.get(django_instance_model)
                 redis_value = [
                     await get_or_create_redis_instance_from_django_instance(
                         django_many_to_many_instance,
                         redis_root,
-                        all_redis_instances,
                         cache_conf,
                     )
                     for django_many_to_many_instance in django_many_to_many_instances
@@ -521,41 +513,15 @@ async def django_instance_to_redis_params(
     return redis_params
 
 
-def get_redis_instance_by_django_id_from_all_redis_instances(
-        django_id,
-        all_redis_instances
-):
-    all_django_ids = []
-    for redis_instance in all_redis_instances:
-        django_id = None
-        if 'django_id' in redis_instance.keys():
-            django_id = redis_instance['django_id']
-        all_django_ids.append(django_id)
-    try:
-        index_of_redis_instance = all_django_ids.index(django_id)
-        redis_instance = all_redis_instances[index_of_redis_instance]
-    except:
-        redis_instance = None
-    return redis_instance
-
-
 async def get_or_create_redis_instance_from_django_instance(
         django_instance,
         redis_root,
-        all_redis_instances,
         cache_conf,
 ):
     django_fields = django_instance.__class__._meta.get_fields()
-
-    redis_instance = get_redis_instance_by_django_id_from_all_redis_instances(
-        django_instance.id,
-        all_redis_instances
-    )
-
     django_instance_model = django_instance.__class__
-    print('Foreign', django_instance_model, django_instance.id)
+    redis_instance = redis_root.get(django_instance_model, django_id=django_instance.id)
 
-    print(not redis_instance)
     if not redis_instance:
         redis_dict = await django_instance_to_redis_params(
             redis_root,
@@ -568,5 +534,7 @@ async def get_or_create_redis_instance_from_django_instance(
             django_id=django_instance.id,
             **redis_dict
         )
+    else:
+        redis_instance = redis_instance[0]
 
     return redis_instance
