@@ -1,4 +1,3 @@
-import asyncio
 import datetime
 import decimal
 import json
@@ -8,8 +7,6 @@ from typing import Callable
 from django.db import models as django_models
 from .utils import check_types, check_classes, get_ids_from_untyped_data
 from .cache import default_cache_func
-from time import sleep
-
 
 class RedisField:
 
@@ -20,7 +17,6 @@ class RedisField:
         self.choices = choices
         self.null = null
 
-
     def _get_default_value(self):
         if self.default is not None:
             try:
@@ -599,7 +595,7 @@ class RedisRoot:
 
 
     def fast_get_keys_values(self, string):
-        keys = list(self.redis_instance.scan_iter(string))
+        keys = list(self.redis_instance.keys(string))
         values = self.redis_instance.mget(keys)
         results = dict(zip(keys, values))
         return results
@@ -1013,14 +1009,14 @@ class RedisRoot:
         model_name = model.__name__
         updated_datas = []
         if instances is None:
-            for key in self.redis_instance.scan_iter(f'{self.prefix}:{model_name}:*'):
+            for key in self.redis_instance.keys(f'{self.prefix}:{model_name}:*'):
                 updated_data = self._update_by_instance_key(key, fields_to_update, renew_ttl, new_ttl)
                 if updated_data is not None:
                     updated_datas.append(updated_data)
         else:
             ids_to_update = get_ids_from_untyped_data(instances)
             for instance_id in ids_to_update:
-                for key in self.redis_instance.scan_iter(f'{self.prefix}:{model_name}:{instance_id}'):
+                for key in self.redis_instance.keys(f'{self.prefix}:{model_name}:{instance_id}'):
                     updated_data = self._update_by_instance_key(key, fields_to_update, renew_ttl, new_ttl)
                     if updated_data is not None:
                         updated_datas.append(updated_data)
@@ -1044,19 +1040,19 @@ class RedisRoot:
         model = self._django_model_to_redis_model(django_model)
         model_name = model.__name__
         if instances is None:
-            for key in self.redis_instance.scan_iter(f'{self.prefix}:{model_name}:*'):
+            for key in self.redis_instance.keys(f'{self.prefix}:{model_name}:*'):
                 self._delete_by_key(key)
         else:
             ids_to_delete = get_ids_from_untyped_data(instances)
             for instance_id in ids_to_delete:
-                for key in self.redis_instance.scan_iter(f'{self.prefix}:{model_name}:{instance_id}'):
+                for key in self.redis_instance.keys(f'{self.prefix}:{model_name}:{instance_id}'):
                     self._delete_by_key(key)
 
     # def get_id_from_django_id(self, django_model, django_id):
     #     model_name = django_model.__name__
     #     check_types(django_id, int)
     #     result = False
-    #     for key in self.redis_instance.scan_iter(f'{self.prefix}:{model_name}:*:django_id'):
+    #     for key in self.redis_instance.keys(f'{self.prefix}:{model_name}:*:django_id'):
     #         prefix, model_name, instance_id, field_name = key.split(':')
     #         value = int(self.redis_instance.get(key))
     #         if value == django_id:
@@ -1067,7 +1063,7 @@ class RedisRoot:
     #     model_name = django_model.__name__
     #     check_types(instance_id, int)
     #     result = False
-    #     for key in self.redis_instance.scan_iter(f'{self.prefix}:{model_name}:{instance_id}:edited'):
+    #     for key in self.redis_instance.keys(f'{self.prefix}:{model_name}:{instance_id}:edited'):
     #         prefix, model_name, instance_id, field_name = key.split(':')
     #         value = bool(int(self.redis_instance.get(key)))
     #         result = value
