@@ -852,7 +852,7 @@ class RedisRoot:
 
     def get(self, django_model, return_dict=False, **filters):
         redis_model = self.get_or_create_redis_model_from_django_model(django_model)
-        result = self.get_by_redis_model(redis_model, return_dict=False, **filters)
+        result = self.get_by_redis_model(redis_model, return_dict, **filters)
         return result
 
     def order(self, instances, field_name):
@@ -1088,7 +1088,7 @@ class RedisModel:
         if self.__model_data__['redis_root'].economy:
             deserialized_instance = {'id': self.id.value}
         else:
-            deserialized_instance = redis_root.get(self.__class__, id=self.id.value)[0]
+            deserialized_instance = redis_root.get_by_redis_model(self.__class__, id=self.id.value)[0]
         return deserialized_instance
 
     def set(self, **fields_with_values):
