@@ -52,6 +52,8 @@ def get_ids_from_untyped_data(instances):
                     raise Exception('Not all elements are of the type int')
             except:
                 raise Exception('Not all elements are of the type int')
+    elif type(instances) == int:
+        ids = [instances]
     else:
-        ids = instances
+        raise Exception(f"Can't get ids from {instances}")
     return ids
